<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\BankAccountRequest;
use Bixo\Account\Interfaces\BankAccountRepositoryInterface;
use Bixo\Account\Models\BankAccount;
use Bixo\Account\Forms\BankAccount as Form;

/**
 * APIController  class for bank_account.
 */
class BankAccountAPIController extends BaseController
{

    /**
     * Initialize bank_account resource controller.
     *
     * @param type BankAccountRepositoryInterface $bank_account
     *
     * @return null
     */
    public function __construct(BankAccountRepositoryInterface $bank_account)
    {
        parent::__construct();
        $this->repository = $bank_account;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\BankAccountResourceCriteria::class);
    }

    /**
     * Display a list of bank_account.
     *
     * @return Response
     */
    public function index(BankAccountRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\BankAccountPresenter::class)
            ->paginate();
    }

    /**
     * Display bank_account.
     *
     * @param Request $request
     * @param Model   $bank_account
     *
     * @return Response
     */
    public function show(BankAccountRequest $request, BankAccount $bank_account)
    {
        return $bank_account->setPresenter(\Bixo\Account\Repositories\Presenter\BankAccountListPresenter::class);
        ;
    }

    /**
     * Create new bank_account.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BankAccountRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::bank_account.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/bank_account/' . $bank_account->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/bank_account');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the bank_account.
     *
     * @param Request $request
     * @param Model   $bank_account
     *
     * @return Response
     */
    public function update(BankAccountRequest $request, BankAccount $bank_account)
    {
        try {
            $data = $request->all();

            $bank_account->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::bank_account.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/bank_account/' . $bank_account->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/bank_account/' . $bank_account->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the bank_account.
     *
     * @param Model   $bank_account
     *
     * @return Response
     */
    public function destroy(BankAccountRequest $request, BankAccount $bank_account)
    {
        try {
            $bank_account->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::bank_account.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/bank_account/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/bank_account/' . $bank_account->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
