<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\CoaRequest;
use Bixo\Account\Interfaces\CoaRepositoryInterface;
use Bixo\Account\Models\Coa;
use Bixo\Account\Forms\Coa as Form;

/**
 * APIController  class for coa.
 */
class CoaAPIController extends BaseController
{

    /**
     * Initialize coa resource controller.
     *
     * @param type CoaRepositoryInterface $coa
     *
     * @return null
     */
    public function __construct(CoaRepositoryInterface $coa)
    {
        parent::__construct();
        $this->repository = $coa;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\CoaResourceCriteria::class);
    }

    /**
     * Display a list of coa.
     *
     * @return Response
     */
    public function index(CoaRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\CoaPresenter::class)
            ->paginate();
    }

    /**
     * Display coa.
     *
     * @param Request $request
     * @param Model   $coa
     *
     * @return Response
     */
    public function show(CoaRequest $request, Coa $coa)
    {
        return $coa->setPresenter(\Bixo\Account\Repositories\Presenter\CoaListPresenter::class);
        ;
    }

    /**
     * Create new coa.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CoaRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::coa.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/coa/' . $coa->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/coa');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the coa.
     *
     * @param Request $request
     * @param Model   $coa
     *
     * @return Response
     */
    public function update(CoaRequest $request, Coa $coa)
    {
        try {
            $data = $request->all();

            $coa->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::coa.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/coa/' . $coa->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/coa/' . $coa->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the coa.
     *
     * @param Model   $coa
     *
     * @return Response
     */
    public function destroy(CoaRequest $request, Coa $coa)
    {
        try {
            $coa->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::coa.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/coa/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/coa/' . $coa->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
