<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\InvoiceRequest;
use Bixo\Account\Interfaces\InvoiceRepositoryInterface;
use Bixo\Account\Models\Invoice;
use Bixo\Account\Forms\Invoice as Form;

/**
 * APIController  class for invoice.
 */
class InvoiceAPIController extends BaseController
{

    /**
     * Initialize invoice resource controller.
     *
     * @param type InvoiceRepositoryInterface $invoice
     *
     * @return null
     */
    public function __construct(InvoiceRepositoryInterface $invoice)
    {
        parent::__construct();
        $this->repository = $invoice;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\InvoiceResourceCriteria::class);
    }

    /**
     * Display a list of invoice.
     *
     * @return Response
     */
    public function index(InvoiceRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\InvoicePresenter::class)
            ->paginate();
    }

    /**
     * Display invoice.
     *
     * @param Request $request
     * @param Model   $invoice
     *
     * @return Response
     */
    public function show(InvoiceRequest $request, Invoice $invoice)
    {
        return $invoice->setPresenter(\Bixo\Account\Repositories\Presenter\InvoiceListPresenter::class);
        ;
    }

    /**
     * Create new invoice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InvoiceRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::invoice.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/invoice/' . $invoice->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/invoice');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the invoice.
     *
     * @param Request $request
     * @param Model   $invoice
     *
     * @return Response
     */
    public function update(InvoiceRequest $request, Invoice $invoice)
    {
        try {
            $data = $request->all();

            $invoice->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::invoice.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/invoice/' . $invoice->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/invoice/' . $invoice->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the invoice.
     *
     * @param Model   $invoice
     *
     * @return Response
     */
    public function destroy(InvoiceRequest $request, Invoice $invoice)
    {
        try {
            $invoice->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::invoice.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/invoice/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/invoice/' . $invoice->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
