<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\InvoiceDetailRequest;
use Bixo\Account\Interfaces\InvoiceDetailRepositoryInterface;
use Bixo\Account\Models\InvoiceDetail;
use Bixo\Account\Forms\InvoiceDetail as Form;

/**
 * APIController  class for invoice_detail.
 */
class InvoiceDetailAPIController extends BaseController
{

    /**
     * Initialize invoice_detail resource controller.
     *
     * @param type InvoiceDetailRepositoryInterface $invoice_detail
     *
     * @return null
     */
    public function __construct(InvoiceDetailRepositoryInterface $invoice_detail)
    {
        parent::__construct();
        $this->repository = $invoice_detail;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\InvoiceDetailResourceCriteria::class);
    }

    /**
     * Display a list of invoice_detail.
     *
     * @return Response
     */
    public function index(InvoiceDetailRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\InvoiceDetailPresenter::class)
            ->paginate();
    }

    /**
     * Display invoice_detail.
     *
     * @param Request $request
     * @param Model   $invoice_detail
     *
     * @return Response
     */
    public function show(InvoiceDetailRequest $request, InvoiceDetail $invoice_detail)
    {
        return $invoice_detail->setPresenter(\Bixo\Account\Repositories\Presenter\InvoiceDetailListPresenter::class);
        ;
    }

    /**
     * Create new invoice_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InvoiceDetailRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::invoice_detail.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/invoice_detail/' . $invoice_detail->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/invoice_detail');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the invoice_detail.
     *
     * @param Request $request
     * @param Model   $invoice_detail
     *
     * @return Response
     */
    public function update(InvoiceDetailRequest $request, InvoiceDetail $invoice_detail)
    {
        try {
            $data = $request->all();

            $invoice_detail->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::invoice_detail.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/invoice_detail/' . $invoice_detail->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/invoice_detail/' . $invoice_detail->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the invoice_detail.
     *
     * @param Model   $invoice_detail
     *
     * @return Response
     */
    public function destroy(InvoiceDetailRequest $request, InvoiceDetail $invoice_detail)
    {
        try {
            $invoice_detail->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::invoice_detail.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/invoice_detail/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/invoice_detail/' . $invoice_detail->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
