<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Account\Http\Requests\ReceiptRequest;
use Bixo\Account\Interfaces\ReceiptRepositoryInterface;
use Bixo\Account\Models\Receipt;
use Bixo\Account\Forms\Receipt as Form;

/**
 * APIController  class for receipt.
 */
class ReceiptAPIController extends BaseController
{

    /**
     * Initialize receipt resource controller.
     *
     * @param type ReceiptRepositoryInterface $receipt
     *
     * @return null
     */
    public function __construct(ReceiptRepositoryInterface $receipt)
    {
        parent::__construct();
        $this->repository = $receipt;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Account\Repositories\Criteria\ReceiptResourceCriteria::class);
    }

    /**
     * Display a list of receipt.
     *
     * @return Response
     */
    public function index(ReceiptRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Account\Repositories\Presenter\ReceiptPresenter::class)
            ->paginate();
    }

    /**
     * Display receipt.
     *
     * @param Request $request
     * @param Model   $receipt
     *
     * @return Response
     */
    public function show(ReceiptRequest $request, Receipt $receipt)
    {
        return $receipt->setPresenter(\Bixo\Account\Repositories\Presenter\ReceiptListPresenter::class);
        ;
    }

    /**
     * Create new receipt.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ReceiptRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('account::receipt.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('account/receipt/' . $receipt->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/receipt');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the receipt.
     *
     * @param Request $request
     * @param Model   $receipt
     *
     * @return Response
     */
    public function update(ReceiptRequest $request, Receipt $receipt)
    {
        try {
            $data = $request->all();

            $receipt->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('account::receipt.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('account/receipt/' . $receipt->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/receipt/' . $receipt->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the receipt.
     *
     * @param Model   $receipt
     *
     * @return Response
     */
    public function destroy(ReceiptRequest $request, Receipt $receipt)
    {
        try {
            $receipt->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('account::receipt.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('account/receipt/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('account/receipt/' . $receipt->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
