<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\BankAccount;

class BankAccountPolicy
{

    /**
     * Determine if the given user can view the bank_account.
     *
     * @param UserPolicy $user
     * @param BankAccount $bank_account
     *
     * @return bool
     */
    public function view(UserPolicy $user, BankAccount $bank_account)
    {
        if ($user->canDo('account.bank_account.view') && $user->isAdmin()) {
            return true;
        }

        return $bank_account->user_id == user_id() && $bank_account->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bank_account.
     *
     * @param UserPolicy $user
     * @param BankAccount $bank_account
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.bank_account.create');
    }

    /**
     * Determine if the given user can update the given bank_account.
     *
     * @param UserPolicy $user
     * @param BankAccount $bank_account
     *
     * @return bool
     */
    public function update(UserPolicy $user, BankAccount $bank_account)
    {
        if ($user->canDo('account.bank_account.edit') && $user->isAdmin()) {
            return true;
        }

        return $bank_account->user_id == user_id() && $bank_account->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bank_account.
     *
     * @param UserPolicy $user
     * @param BankAccount $bank_account
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BankAccount $bank_account)
    {
        return $bank_account->user_id == user_id() && $bank_account->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bank_account.
     *
     * @param UserPolicy $user
     * @param BankAccount $bank_account
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BankAccount $bank_account)
    {
        if ($user->canDo('account.bank_account.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bank_account.
     *
     * @param UserPolicy $user
     * @param BankAccount $bank_account
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BankAccount $bank_account)
    {
        if ($user->canDo('account.bank_account.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
