<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\Coa;

class CoaPolicy
{

    /**
     * Determine if the given user can view the coa.
     *
     * @param UserPolicy $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function view(UserPolicy $user, Coa $coa)
    {
        if ($user->canDo('account.coa.view') && $user->isAdmin()) {
            return true;
        }

        return $coa->user_id == user_id() && $coa->user_type == user_type();
    }

    /**
     * Determine if the given user can create a coa.
     *
     * @param UserPolicy $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.coa.create');
    }

    /**
     * Determine if the given user can update the given coa.
     *
     * @param UserPolicy $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function update(UserPolicy $user, Coa $coa)
    {
        if ($user->canDo('account.coa.edit') && $user->isAdmin()) {
            return true;
        }

        return $coa->user_id == user_id() && $coa->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given coa.
     *
     * @param UserPolicy $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Coa $coa)
    {
        return $coa->user_id == user_id() && $coa->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given coa.
     *
     * @param UserPolicy $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Coa $coa)
    {
        if ($user->canDo('account.coa.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given coa.
     *
     * @param UserPolicy $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Coa $coa)
    {
        if ($user->canDo('account.coa.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
