<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\InvoiceDetail;

class InvoiceDetailPolicy
{

    /**
     * Determine if the given user can view the invoice_detail.
     *
     * @param UserPolicy $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function view(UserPolicy $user, InvoiceDetail $invoice_detail)
    {
        if ($user->canDo('account.invoice_detail.view') && $user->isAdmin()) {
            return true;
        }

        return $invoice_detail->user_id == user_id() && $invoice_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can create a invoice_detail.
     *
     * @param UserPolicy $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.invoice_detail.create');
    }

    /**
     * Determine if the given user can update the given invoice_detail.
     *
     * @param UserPolicy $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function update(UserPolicy $user, InvoiceDetail $invoice_detail)
    {
        if ($user->canDo('account.invoice_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $invoice_detail->user_id == user_id() && $invoice_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given invoice_detail.
     *
     * @param UserPolicy $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, InvoiceDetail $invoice_detail)
    {
        return $invoice_detail->user_id == user_id() && $invoice_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given invoice_detail.
     *
     * @param UserPolicy $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function verify(UserPolicy $user, InvoiceDetail $invoice_detail)
    {
        if ($user->canDo('account.invoice_detail.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given invoice_detail.
     *
     * @param UserPolicy $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function approve(UserPolicy $user, InvoiceDetail $invoice_detail)
    {
        if ($user->canDo('account.invoice_detail.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
