<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\Invoice;

class InvoicePolicy
{

    /**
     * Determine if the given user can view the invoice.
     *
     * @param UserPolicy $user
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function view(UserPolicy $user, Invoice $invoice)
    {
        if ($user->canDo('account.invoice.view') && $user->isAdmin()) {
            return true;
        }

        return $invoice->user_id == user_id() && $invoice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a invoice.
     *
     * @param UserPolicy $user
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.invoice.create');
    }

    /**
     * Determine if the given user can update the given invoice.
     *
     * @param UserPolicy $user
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function update(UserPolicy $user, Invoice $invoice)
    {
        if ($user->canDo('account.invoice.edit') && $user->isAdmin()) {
            return true;
        }

        return $invoice->user_id == user_id() && $invoice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given invoice.
     *
     * @param UserPolicy $user
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Invoice $invoice)
    {
        return $invoice->user_id == user_id() && $invoice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given invoice.
     *
     * @param UserPolicy $user
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Invoice $invoice)
    {
        if ($user->canDo('account.invoice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given invoice.
     *
     * @param UserPolicy $user
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Invoice $invoice)
    {
        if ($user->canDo('account.invoice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
