<?php

namespace Bixo\Account\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Account\Models\Receipt;

class ReceiptPolicy
{

    /**
     * Determine if the given user can view the receipt.
     *
     * @param UserPolicy $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function view(UserPolicy $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.view') && $user->isAdmin()) {
            return true;
        }

        return $receipt->user_id == user_id() && $receipt->user_type == user_type();
    }

    /**
     * Determine if the given user can create a receipt.
     *
     * @param UserPolicy $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('account.receipt.create');
    }

    /**
     * Determine if the given user can update the given receipt.
     *
     * @param UserPolicy $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function update(UserPolicy $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.edit') && $user->isAdmin()) {
            return true;
        }

        return $receipt->user_id == user_id() && $receipt->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given receipt.
     *
     * @param UserPolicy $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Receipt $receipt)
    {
        return $receipt->user_id == user_id() && $receipt->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given receipt.
     *
     * @param UserPolicy $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param UserPolicy $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
