<?php

namespace Bixo\Account\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Bixo\Account\Models\Account;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Account\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/account/customer/*')) {
            Route::bind('customer', function ($customer) {
                $customerrepo = $this->app->make('Bixo\Account\Interfaces\CustomerRepositoryInterface');
                return $customerrepo->findorNew($customer);
            });
        }
        if (Request::is('*/account/invoice/*')) {
            Route::bind('invoice', function ($invoice) {
                $invoicerepo = $this->app->make('Bixo\Account\Interfaces\InvoiceRepositoryInterface');
                return $invoicerepo->findorNew($invoice);
            });
        }
        if (Request::is('*/account/invoice_detail/*')) {
            Route::bind('invoice_detail', function ($invoice_detail) {
                $invoice_detailrepo = $this->app->make('Bixo\Account\Interfaces\InvoiceDetailRepositoryInterface');
                return $invoice_detailrepo->findorNew($invoice_detail);
            });
        }
        if (Request::is('*/account/product/*')) {
            Route::bind('product', function ($product) {
                $productrepo = $this->app->make('Bixo\Account\Interfaces\ProductRepositoryInterface');
                return $productrepo->findorNew($product);
            });
        }
        if (Request::is('*/account/receipt/*')) {
            Route::bind('receipt', function ($receipt) {
                $receiptrepo = $this->app->make('Bixo\Account\Interfaces\ReceiptRepositoryInterface');
                return $receiptrepo->findorNew($receipt);
            });
        }
        if (Request::is('*/account/bank_account/*')) {
            Route::bind('bank_account', function ($bank_account) {
                $bank_accountrepo = $this->app->make('Bixo\Account\Interfaces\BankAccountRepositoryInterface');
                return $bank_accountrepo->findorNew($bank_account);
            });
        }
        if (Request::is('*/account/coa/*')) {
            Route::bind('coa', function ($coa) {
                $coarepo = $this->app->make('Bixo\Account\Interfaces\CoaRepositoryInterface');
                return $coarepo->findorNew($coa);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
